==> jc-1.4.0.tar.gz: javax/naming/directory/AttributeModificationException.h <==
// public class javax.naming.directory.AttributeModificationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 4aad88032eb088ca javax_naming_directory_AttributeModificationException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_directory_AttributeModificationException_H_
#define _JC_javax_naming_directory_AttributeModificationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_directory_AttributeModificationException$sub_refs	_jc_javax_naming_directory_AttributeModificationException$sub_refs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$sub_nonrefs	_jc_javax_naming_directory_AttributeModificationException$sub_nonrefs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$refs	_jc_javax_naming_directory_AttributeModificationException$refs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$nonrefs	_jc_javax_naming_directory_AttributeModificationException$nonrefs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$object	_jc_javax_naming_directory_AttributeModificationException$object;

typedef const struct _jc_javax_naming_directory_AttributeModificationException$vmethods	_jc_javax_naming_directory_AttributeModificationException$vmethods;
typedef const struct _jc_javax_naming_directory_AttributeModificationException$vtable	_jc_javax_naming_directory_AttributeModificationException$vtable;
typedef const struct _jc_javax_naming_directory_AttributeModificationException$vtype	_jc_javax_naming_directory_AttributeModificationException$vtype;

// Constructors
extern void _jc_javax_naming_directory_AttributeModificationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *);
extern void _jc_javax_naming_directory_AttributeModificationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_naming_directory_AttributeModificationException$method$getUnexecutedModifications$c17f66df6472f540(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *);
extern void _jc_javax_naming_directory_AttributeModificationException$method$setUnexecutedModifications$9c229600aff06678(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *, struct _jc_object_array *);
extern struct _jc_java_lang_String$object *_jc_javax_naming_directory_AttributeModificationException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_AttributeModificationException$method_info$getUnexecutedModifications$c17f66df6472f540;
extern _jc_method _jc_javax_naming_directory_AttributeModificationException$method_info$setUnexecutedModifications$9c229600aff06678;
extern _jc_method _jc_javax_naming_directory_AttributeModificationException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_directory_AttributeModificationException$vmethods {
	_jc_object_array	*(*getUnexecutedModifications$c17f66df6472f540)(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *);
	void	(*setUnexecutedModifications$9c229600aff06678)(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *, struct _jc_object_array *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *);
};

// Vtable
struct _jc_javax_naming_directory_AttributeModificationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_directory_AttributeModificationException$vmethods	javax_naming_directory_AttributeModificationException;
};

// Vtype
struct _jc_javax_naming_directory_AttributeModificationException$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_AttributeModificationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_AttributeModificationException$sub_refs {
	_jc_object_array	*unexecs;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_AttributeModificationException$refs {
    _jc_javax_naming_directory_AttributeModificationException$sub_refs	javax_naming_directory_AttributeModificationException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_AttributeModificationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_AttributeModificationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_directory_AttributeModificationException$sub_nonrefs	javax_naming_directory_AttributeModificationException;
};

// Object instance structure
struct _jc_javax_naming_directory_AttributeModificationException$object {
	_jc_javax_naming_directory_AttributeModificationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_AttributeModificationException$vtype	*vtype;
	_jc_javax_naming_directory_AttributeModificationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_AttributeModificationException$vtype _jc_javax_naming_directory_AttributeModificationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_AttributeModificationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_AttributeModificationException$class_object;

#endif	/* _JC_javax_naming_directory_AttributeModificationException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/directory/AttributeModificationException.h <==
// public class javax.naming.directory.AttributeModificationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 4aad88032eb088ca javax_naming_directory_AttributeModificationException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_directory_AttributeModificationException_H_
#define _JC_javax_naming_directory_AttributeModificationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_directory_AttributeModificationException$sub_refs	_jc_javax_naming_directory_AttributeModificationException$sub_refs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$sub_nonrefs	_jc_javax_naming_directory_AttributeModificationException$sub_nonrefs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$refs	_jc_javax_naming_directory_AttributeModificationException$refs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$nonrefs	_jc_javax_naming_directory_AttributeModificationException$nonrefs;
typedef struct _jc_javax_naming_directory_AttributeModificationException$object	_jc_javax_naming_directory_AttributeModificationException$object;

typedef const struct _jc_javax_naming_directory_AttributeModificationException$vmethods	_jc_javax_naming_directory_AttributeModificationException$vmethods;
typedef const struct _jc_javax_naming_directory_AttributeModificationException$vtable	_jc_javax_naming_directory_AttributeModificationException$vtable;
typedef const struct _jc_javax_naming_directory_AttributeModificationException$vtype	_jc_javax_naming_directory_AttributeModificationException$vtype;

// Constructors
extern void _jc_javax_naming_directory_AttributeModificationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_AttributeModificationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_naming_directory_AttributeModificationException$method$getUnexecutedModifications$c17f66df6472f540(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_directory_AttributeModificationException$method$setUnexecutedModifications$9c229600aff06678(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_naming_directory_AttributeModificationException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_AttributeModificationException$method_info$getUnexecutedModifications$c17f66df6472f540;
extern _jc_method _jc_javax_naming_directory_AttributeModificationException$method_info$setUnexecutedModifications$9c229600aff06678;
extern _jc_method _jc_javax_naming_directory_AttributeModificationException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_directory_AttributeModificationException$vmethods {
	_jc_object_array	*(*getUnexecutedModifications$c17f66df6472f540)(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *) _JC_JCNI_ATTR;
	void	(*setUnexecutedModifications$9c229600aff06678)(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_directory_AttributeModificationException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_directory_AttributeModificationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_directory_AttributeModificationException$vmethods	javax_naming_directory_AttributeModificationException;
};

// Vtype
struct _jc_javax_naming_directory_AttributeModificationException$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_AttributeModificationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_AttributeModificationException$sub_refs {
	_jc_object_array	*unexecs;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_AttributeModificationException$refs {
    _jc_javax_naming_directory_AttributeModificationException$sub_refs	javax_naming_directory_AttributeModificationException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_AttributeModificationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_AttributeModificationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_directory_AttributeModificationException$sub_nonrefs	javax_naming_directory_AttributeModificationException;
};

// Object instance structure
struct _jc_javax_naming_directory_AttributeModificationException$object {
	_jc_javax_naming_directory_AttributeModificationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_AttributeModificationException$vtype	*vtype;
	_jc_javax_naming_directory_AttributeModificationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_AttributeModificationException$vtype _jc_javax_naming_directory_AttributeModificationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_AttributeModificationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_AttributeModificationException$class_object;

#endif	/* _JC_javax_naming_directory_AttributeModificationException_H_ */
